/*
 * Copyright (c) 2011 Imre Fazekas.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the Brillien nor the names of its
 * terms and concepts may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.vii.brillien.ignition.jmx.mbeans;

import com.vii.brillien.ignition.jmx.BeanStatics;

import javax.management.Attribute;
import javax.management.MBeanServerConnection;
import java.lang.management.ClassLoadingMXBean;

/**
 * Specialized AbstractBeanWrapper to provide ClassLoadingMXBean services
 */
public class ClassLoadingImpl extends AbstractBeanWrapper implements ClassLoadingMXBean {

    public ClassLoadingImpl(MBeanServerConnection mbsc) {
        super( mbsc, BeanStatics.CLASSLOADING_BEAN_NAME );
    }

    public long getTotalLoadedClassCount() {
        return get(  "TotalLoadedClassCount", -1l );
    }

    public int getLoadedClassCount() {
        return get(  "LoadedClassCount", -1 );
    }

    public long getUnloadedClassCount() {
        return get(  "UnloadedClassCount", -1l );
    }

    public boolean isVerbose() {
        return get(  "Verbose", false );
    }

    public void setVerbose(boolean value) {
        set( new Attribute("Verbose", value) );
    }
}
