/*
 * Copyright (c) 2011 Imre Fazekas.
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * Neither the name of the Brillien nor the names of its
 * terms and concepts may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package com.vii.brillien.ignition.jmx.mbeans;


import com.vii.brillien.ignition.jmx.BeanStatics;
import com.vii.brillien.kernel.BrillienException;

import javax.management.Attribute;
import javax.management.MBeanServerConnection;
import java.util.List;

/**
 * Specialized AbstractBeanWrapper to provide LiaisonMXBean services
 */
public class LiaisonImpl extends AbstractBeanWrapper {

    /**
     * Creates new LiaisonImpl instance
     */
    public LiaisonImpl(MBeanServerConnection mbsc) {
        super(mbsc, BeanStatics.LIAISON_BEAN_NAME);
    }

    /**
     * Getter method for the configuration of a Brillien instance as a matrix of String
     */
    public String[][] getConfigProperties(){
        return get( "ConfigProperties", null );
    }

    /**
     * Setter method for Brillien's configuration. This method writes the configuration to the proper XML file.
     * @param newConfig
     * @throws BrillienException
     */
    public void setConfigProperties( String[][] newConfig ) throws BrillienException {
        set( new Attribute( "ConfigProperties", newConfig ) );
    }

    /**
     * Getter method for all published Presence names
     */
    public List<String> getPublishedPresencesNames(){
        return get( "PublishedPresencesNames", null );
    }

    /**
     * Getter method for all properties of a given presence type identified by name.
     * This should include:
     * - logging type
     * - instantiation policy
     * - WS capability
     * etc.
     * Basically all information that can be defined by declaring annotations and creating deployment descriptor.
     * @param PresenceName name of the Presence
     * @return properties
     */
    public String[][] getPresenceProperties( String PresenceName ){
        return invoke( "getPresenceProperties",
                new Object[]{ PresenceName },
                new String[]{ String.class.getName() },
                null
        );
    }

    /**
     * Getter method for the version of the server
     */
    public Float getServerVersion(){
        return get( "ServerVersion", null );
    }

    /**
     * Makes the application server shut down
     */
    public void shutDown(){
        invoke( "shutDown", null );
    }

    /**
     * Checks the validity of the given username and password
     * @param username username
     * @param password password
     * @return boolean value of validity
     */
    public boolean isValidLogin(String username, String password){
        return invoke( "isValidLogin",
                new Object[]{ username, password },
                new String[]{ String.class.getName(), String.class.getName() },
                false
        );
    }

}
